DebugAutoFillerHandler class

Constructors

DebugAutoFillerHandler()

Properties

currentProfile DebugProfile
no setter
hashCode int
The hash code for this object.
no setterinherited
radioList List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyDebugValues() → void
getProfiles() List<DebugProfile>
getValue(DebugInputFillerKeys key) → dynamic
hasProfile() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh(Element element) → void
setProfileIndex(int index) → void
switchOff(Element element) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited