DebugProfileAuto class
- Inheritance
-
- Object
- DebugProfile
- DebugProfileAuto
Constructors
- DebugProfileAuto()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Map<
InputTypes, dynamic> -
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited