DebugInputFillerKeys class abstract

Inheritance
Implementers

Constructors

DebugInputFillerKeys({required InputTypes type, required int counter})
const

Properties

counter int
final
hashCode int
The hash code for this object.
no setterinherited
keyName String
no setter
keyType → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InputTypes
final
value String
The value to which this key delegates its operator==.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited