Text1Key class
Constructors
- Text1Key()
Properties
- counter → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyName → String
-
no setterinherited
- keyType → dynamic
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → InputTypes
-
finalinherited
- value → String
-
The value to which this key delegates its operator==.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited